package model;


/**
 * Created by IntelliJ IDEA.
 * User: Amir  Sheibani
 * Date: Mar 31, 2004
 * Time: 4:52:52 PM
 * To change this template use Options | File Templates.
 */
public class ImageRGBData {

    final private int[] data;
    final private int width;
    final private int height;
    final private int size;

    public ImageRGBData(final int[] data, final int width, final int height) {
        this.data = data;
        this.width = width;
        this.height = height;
        this.size = data.length;
    }

    public int getRed(final int i) {
        // data is in int 32bit format (alpha, red, green, blue): aaaaaaaarrrrrrrrggggggggbbbbbbbb
        // we just need the reds (alpha's are zero)
        return (data[i] >> 16) & 0xFF;
    }

    public int getRed(final int x, final int y) {
        // data is in int 32bit format (alpha, red, green, blue): aaaaaaaarrrrrrrrggggggggbbbbbbbb
        // we just need the reds (alpha's are zero)
        return (data[y*width+x] >> 16) & 0xFF;
    }

    public int[] getData() {
        return data;
    }

    public int getWidth() {
        return width;
    }

    public int getHeight() {
        return height;
    }

    public int getSize() {
        return size;
    }

    /***********************************************************************************************/
    /***********************************************************************************************/
    /***********************************************************************************************/
    /***********************************************************************************************/

    public GridMacroBlock getGridMacroBlock(int pos) {
        final int blockWidth = width / MacroBlock.DEFAULT_SIZE;
        return getGridMacroBlock(pos % blockWidth, pos / blockWidth);
    }

    public GridMacroBlock getGridMacroBlock(int x, int y) {
        return new GridMacroBlock(this, x, y);
    }

    public IGridMacroBlockIterator getMacroBlockIterator() {

        return new IGridMacroBlockIterator() {
            final int blockWidth = width / MacroBlock.DEFAULT_SIZE;
            final int blockheight = height / MacroBlock.DEFAULT_SIZE;
            final int blockDimension = blockWidth * blockheight;
            int counter = 0;

            public GridMacroBlock nextMacroBlock()
            {
                return (GridMacroBlock) next();
            }

            public boolean hasNext()
            {
                return counter < blockDimension;
            }

            public Object next()
            {
                counter++;
                return new GridMacroBlock(ImageRGBData.this, (counter-1) % blockWidth, (counter-1) / blockWidth);
            }

            public void remove()
            {
                throw new UnsupportedOperationException();
            }
        };
    }
}
