package model;


/**
 * Created by IntelliJ IDEA.
 * User: Amir  Sheibani
 * Date: Apr 2, 2004
 * Time: 7:28:34 PM
 * To change this template use Options | File Templates.
 */
public class MacroBlock {

    public static final int DEFAULT_SIZE = 16;

    final protected ImageRGBData data;
    protected final int size; // can there be no default blocks (i.e. smaller than 16)? not used as of yet..

    protected int origin;

    public MacroBlock(final ImageRGBData data, final int origin) {
        this.data = data;
        this.origin = origin;
        this.size = DEFAULT_SIZE;
    }

    protected MacroBlock(final ImageRGBData data) {
        this.data = data;
        this.size = DEFAULT_SIZE;
    }





    public int getRed(final int subX, final int subY) {
        if (subX >= DEFAULT_SIZE || subY >= DEFAULT_SIZE || subX < 0 || subY < 0) {
            throw new IllegalArgumentException("Coordinates non-negative and must be less than " + DEFAULT_SIZE);
        }
        return data.getRed(getCoordinate(subX, subY));
    }

    public int getCoordinate(int subX, int subY) {
        return origin + (data.getWidth() * subY) + subX;
    }

    public boolean hasRight() {
        int current = origin % data.getWidth();
        int next = (origin + DEFAULT_SIZE) % data.getWidth();
        return current < next;
    }

    public boolean hasBottom() {
        int next = origin + (data.getWidth() * DEFAULT_SIZE);
        return next < data.getSize();
    }

    public boolean hasLeft() {
        int current = origin % data.getWidth();
        int next = (origin - DEFAULT_SIZE) % data.getWidth();
        return next < current;
    }

    public boolean hasTop() {
        int next = origin - (data.getWidth() * DEFAULT_SIZE);
        return next >= 0;
    }

}
